// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"
#include "display/RenderHost.hpp"
#include "input/InputManager.hpp"

namespace Dawn {
  class Game : public std::enable_shared_from_this<Game> {
    public:
      RenderHost renderHost;
      InputManager inputManager;

      /**
       * Constructs the game instance, does not initialize anything.
       */
      Game();

      /**
       * Initialize the game and all of its components.
       */
      void init();

      /**
       * Performs a single update tick on the game engine, and in turn all of
       * the game's sub systems.
       */
      void update();

      /**
       * Returns whether the game has been requested to gracefully close at the
       * next available opportunity.
       * 
       * @return True if the game should close.
       */
      bool_t isCloseRequested();

      /**
       * Deconstructs the game instance, does not deinitialize anything.
       */
      virtual ~Game();
  };
}