// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"
#include <glad/glad.h>
#include <GLFW/glfw3.h>

#define DAWN_GLFW_WINDOW_WIDTH_DEFAULT 1280
#define DAWN_GLFW_WINDOW_HEIGHT_DEFAULT 720

namespace Dawn {
  class RenderHost {
    public:
      GLFWwindow *window = nullptr;

      /**
       * Initializes the GLFW RenderHost.
       */
      RenderHost();

      /**
       * Initializes GLFW and creates the window.
       */
      void init();

      /**
       * Performs an update and renders the frame.
       */
      void update();
    
      /**
       * Returns whether or not GLFW has been requested to close.
       * 
       * @return True if GLFW has been requested to close.
       */
      bool_t isCloseRequested();

      /**
       * Cleans up GLFW.
       */
      virtual ~RenderHost();
  };
}