// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "input/IInputManager.hpp"

namespace Dawn {
  class Game;

  class InputManager : public IInputManager<int32_t> {
    protected:
      std::unordered_map<int32_t, float_t> rawInputValues;

      float_t getInputValue(int32_t axis) override;

    public:
      /**
       * Initializes the input manager system.
       * 
       * @param game Game that this input manager is for.
       */
      void init(const std::shared_ptr<Game> game);

      /**
       * Cleans up the GLFW input manager.
       */
      ~InputManager();
  };
}